package com.persagy.dmp.rwd.datautils;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.JsonNodeFactory;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.date.DateUtils;
import com.persagy.common.json.JacksonMapper;
import com.persagy.dmp.common.http.HttpUtils;
import com.persagy.dmp.rwd.dic.DataTypeMapping;
import com.persagy.dmp.rwd.dic.ExcelUtils;
import com.persagy.dmp.rwd.dic.FuncidDefModel;
import com.persagy.dmp.rwd.dic.FuncidUtils;
import com.persagy.dmp.rwd.enums.FuncidDataType;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import java.io.*;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;

/**
 * @author: yaoll
 * @date: 2020-11-30
 * @verison: 1.0
 */
@Slf4j
@SpringBootTest
@RunWith(SpringRunner.class)
public class ImportFuncid {

    private String basepath = "C:\\Users\\24341\\Downloads\\数据字典附表(20210503)";

    private String outPath = "C:/Users/24341/Downloads/20210512/funcid-" + DateUtils.format(new Date()) + ".dml.sql";

    @Autowired
    private HttpUtils httpUtils;

    @Value("${persagy.dmp.rwdedit.server}")
    private String rwdeditServer;

    @Before
    public void init() {
        FuncidUtils.httpUtils = httpUtils;
        FuncidUtils.rwdeditServer = rwdeditServer;
    }

    @Test
    public void importFuncidDef() throws IOException {
        List<FuncidDefModel> funcids = new LinkedList<>();
        //importBase(funcids);
        importSpace(funcids);
        importSystem(funcids);
        importEquipment(funcids);
        importComponent(funcids);
        importVirtual(funcids);
        importTool(funcids);
        importMaterial(funcids);

        FileOutputStream fos = new FileOutputStream(outPath);
        PrintWriter writer = new PrintWriter(new BufferedOutputStream(fos));
        writer.println("delete from rwd_def_funcid where code not in ('id', 'name', 'localId', 'localName');");
        writer.println("commit;");
        funcids.forEach(item -> {
//			System.out.println(JacksonMapper.toSimpleJson(item));
            writer.println(toSql(item));
        });
        writer.println("commit;");
        writer.flush();
        writer.close();
    }

    private void importBase(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("system", "/附表6-机电精装类对象通用属性点表.xlsx", "系统类"));
        funcids.addAll(readSheet("equipment", "/附表6-机电精装类对象通用属性点表.xlsx", "设备类"));
        funcids.addAll(readSheet("component", "/附表6-机电精装类对象通用属性点表.xlsx", "部件类"));

    }

    private String toSql(FuncidDefModel model) {
        StringBuilder buff = new StringBuilder("");
        buff.append("insert into rwd_def_funcid ");
        buff.append("(id,code,orig_code,name,alias_code,alias_name,class_code,type,group_code,project_id,category,");
        buff.append("first_tag,second_tag,priority,input_mode,unit,data_type,orig_data_type,is_multiple,is_region,formater,data_source,orig_data_source,note,sub_flag,weak_point) \n");
        buff.append("values (");
        buff.append("'").append(UUID.randomUUID().toString().replace("-", "")).append("',"); // id
        buff.append("'").append(model.getCode()).append("',"); // code
        buff.append("'").append(model.getOrigCode()).append("',"); // orig_code
        buff.append("'").append(model.getName()).append("',"); // name
        buff.append("'").append(model.getAliasCode()).append("',"); // alias_code
        buff.append("'").append(model.getAliasName()).append("',"); // alias_name
        buff.append("'").append(model.getClassCode()).append("',"); // class_code
        buff.append("'").append(model.getType()).append("',"); // type
        buff.append("'").append(model.getGroupCode()).append("',"); // group_code
        buff.append("'").append(model.getProjectId()).append("',"); // project_id
        buff.append("'").append(model.getCategory().name()).append("',"); // category
        if (model.getFirstTag() != null) {
            buff.append("'").append(model.getFirstTag()).append("',"); // first_tag
        } else {
            buff.append("null,");
        }
        if (model.getSecondTag() != null) {
            buff.append("'").append(model.getSecondTag()).append("',"); // second_tag
        } else {
            buff.append("null,");
        }
        if (model.getPriority() != null) {
            buff.append("'").append(model.getPriority()).append("',"); // priority
        } else {
            buff.append("null,");
        }
        if (model.getInputMode() != null) {
            buff.append("'").append(model.getInputMode()).append("',"); // input_mode
        } else {
            buff.append("null,");
        }
        if (model.getUnit() != null) {
            buff.append("'").append(model.getUnit()).append("',"); // unit
        } else {
            buff.append("null,");
        }

        buff.append("'").append(model.getDataType().name()).append("',"); // data_type
        buff.append("'").append(model.getOrigDataType()).append("',"); // orig_data_type
        buff.append(model.getIsMultiple() ? 1 : 0).append(","); // is_multiple
        buff.append(model.getIsRegion() ? 1 : 0).append(","); // is_region
        if (model.getFormater() != null) {
            buff.append("'").append(model.getFormater()).append("',"); // formater
        } else {
            buff.append("null,");
        }
        if (model.getDataSource() != null) {
            buff.append("'").append(model.getDataSource().toString()).append("',"); // data_source
        } else {
            buff.append("null,");
        }
        if (model.getOrigDataSource() != null) { // orig_data_source
            buff.append("'").append(model.getOrigDataSource()).append("',"); // data_source
        } else {
            buff.append("null,");
        }
        if (model.getNote() != null) {
            buff.append("'").append(model.getNote()).append("',"); // note}
        } else {
            buff.append("null,");
        }
        buff.append(model.getSubFlag() ? 1 : 0).append(","); // sub_flag
        buff.append(model.getWeakPoint() ? 1 : 0).append(","); // weak_point
        buff.deleteCharAt(buff.length() - 1);
        buff.append(");");
        return buff.toString();
    }

    private FuncidDefModel toFuncidDefModel(CacheModel model) {
        FuncidDefModel funcid = new FuncidDefModel();
        funcid.setGroupCode("0");
        funcid.setProjectId("0");
        funcid.setType("common");
        funcid.setClassCode(model.classCode);
        funcid.setFirstTag(model.firstTag != null ? model.firstTag.replace("\n", "") : null);
        funcid.setSecondTag(model.secondTag != null ? model.secondTag.replace("\n", "") : null);
        funcid.setCode(model.origCode.substring(0, 1).toLowerCase() + model.origCode.substring(1));
        funcid.setOrigCode(model.origCode);
        funcid.setAliasCode(model.origCode);
        if (model.name != null) {
            funcid.setName(model.name.replace("\n", ""));
            funcid.setAliasName(model.name.replace("\n", ""));
        } else {
            log.error("funcid name is null : {}", JacksonMapper.toSimpleJson(funcid));
        }
        funcid.setUnit(model.unit);
        funcid.setPriority(model.priority);
        funcid.setInputMode(model.inputMode);
        funcid.setOrigDataType(model.origDataType);
        funcid.setSubFlag(false);
        funcid.setWeakPoint(false);
        FuncidDefModel dataType = DataTypeMapping.getDataType(model.origDataType);
        if (dataType != null) {
            funcid.setCategory(dataType.getCategory());
            funcid.setDataType(dataType.getDataType());
            funcid.setIsMultiple(dataType.getIsMultiple());
            funcid.setIsRegion(dataType.getIsRegion());
        } else {
            return null;
        }
        funcid.setSubFlag(false);
        if (model.remark != null) {
            funcid.setNote(model.remark.replace("\n", ""));
            if (model.remark != null) {
                if (model.remark.contains("YYYYMMDD-YYYYMMDD")) {
                    funcid.setFormater("YYYYMMDD-YYYYMMDD");
                }else if (model.remark.contains("YYYYMMDD")) {
                    funcid.setFormater("YYYYMMDD");
                }else if (model.remark.contains("YYYY")) {
                    funcid.setFormater("YYYY");
                }
            }
        }

        if (model.origDataSource != null) {
            funcid.setOrigDataSource(model.origDataSource.replace("\n", "nn")); // 去掉换行符
        }
        if (funcid.getDataType() == FuncidDataType.ENUM || funcid.getDataType() == FuncidDataType.MENUM || funcid.getDataType() == FuncidDataType.BOOLEAN) {
            funcid.setDataSource(FuncidUtils.transEnumDataSource(model.origDataSource)); // 解析datasource
        }
        return funcid;
    }

    private void importSpace(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("project", "/附表5-建筑空间类对象属性点表/附表5.1-项目.xlsx", "项目"));
        funcids.addAll(readSheet("building", "/附表5-建筑空间类对象属性点表/附表5.2-建筑.xlsx", "建筑"));
        funcids.addAll(readSheet("floor", "/附表5-建筑空间类对象属性点表/附表5.3-楼层.xlsx", "楼层"));
        funcids.addAll(readSheet("shaft", "/附表5-建筑空间类对象属性点表/附表5.4-竖井.xlsx", "竖井"));
        funcids.addAll(readSheet("GeneralZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "CMZ物业分区"));
        funcids.addAll(readSheet("PowerSupplyZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "PSZ供电分区"));
        funcids.addAll(readSheet("LightingZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "LTZ照明分区"));
        funcids.addAll(readSheet("NetworkZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "NWZ网络分区"));
        funcids.addAll(readSheet("AirConditioningZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "ACZ空调分区"));
        funcids.addAll(readSheet("HeatingZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "HTZ采暖分区"));
        funcids.addAll(readSheet("CleanZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "CLZ洁净分区"));
        funcids.addAll(readSheet("DomesticWaterSupplyZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "DWZ生活给水分区"));
        funcids.addAll(readSheet("FireZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "FRZ防火分区"));
        funcids.addAll(readSheet("SecurityZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "SCZ安防分区"));
        funcids.addAll(readSheet("TenantZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "TNZ租户分区"));
        funcids.addAll(readSheet("FunctionZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "FCZ功能分区"));
        funcids.addAll(readSheet("PassengerFlowZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "PFZ客流分区"));
        funcids.addAll(readSheet("EvacuateZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "EVZ疏散分区"));
        funcids.addAll(readSheet("EnvironmentZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "ENZ环境分区"));
        funcids.addAll(readSheet("OtherZone", "/附表5-建筑空间类对象属性点表/附表5.5-空间.xlsx", "OTZ其他分区"));
    }

    private void importSystem(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("system", "/附表6-机电精装类对象通用属性点表.xlsx", "系统类"));

        funcids.addAll(readSheet("SETD", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "TD变配电系统 "));
        funcids.addAll(readSheet("SEDG", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "DG柴发机房系统"));
        funcids.addAll(readSheet("SEBP", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "BP备用电源系统"));
        funcids.addAll(readSheet("SEEP", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "EP机房动力系统"));
        funcids.addAll(readSheet("SEOP", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "OP室外动力系统"));
        funcids.addAll(readSheet("SEEL", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "EL电梯系统"));
        funcids.addAll(readSheet("SELT", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "LT照明系统"));
        funcids.addAll(readSheet("SETP", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "TP租户配电系统"));
        funcids.addAll(readSheet("SELP", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "LP雷电防护系统"));
        funcids.addAll(readSheet("SESD", "/附表7-系统类对象分类属性点表/附表7.1-强电专业系统.xlsx", "SD强电人防系统"));
        funcids.addAll(readSheet("WEBA", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "BA建筑设备控制系统"));
        funcids.addAll(readSheet("WETV", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "TV电视信号系统"));
        funcids.addAll(readSheet("WEMI", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "MI多媒体信息发布系统  "));
        funcids.addAll(readSheet("WEWT", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "WT无线对讲系统   "));
        funcids.addAll(readSheet("WEGM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "GM车库管理系统"));
        funcids.addAll(readSheet("WELN", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "LN本地网络系统"));
        funcids.addAll(readSheet("WEMA", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "MA移动通信信号放大系统"));
        funcids.addAll(readSheet("WETM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "TM租户管理系统"));
        funcids.addAll(readSheet("WEPM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "PM客流管理系统"));
        funcids.addAll(readSheet("WEEM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "EM能源管理系统"));
        funcids.addAll(readSheet("WEMM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "MM气象监测系统"));
        funcids.addAll(readSheet("WECM", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "CM收银管理系统"));
        funcids.addAll(readSheet("WEOF", "/附表7-系统类对象分类属性点表/附表7.2-弱电专业系统.xlsx", "OF办公系统"));
        funcids.addAll(readSheet("ACCC", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "CC中央供冷系统 "));
        funcids.addAll(readSheet("ACCH", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "CH中央供热系统"));
        funcids.addAll(readSheet("ACAT", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "AT空调末端系统"));
        funcids.addAll(readSheet("ACVT", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "VT通风系统"));
        funcids.addAll(readSheet("ACKL", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "KL厨房排油烟系统"));
        funcids.addAll(readSheet("ACAD", "/附表7-系统类对象分类属性点表/附表7.3-空调专业系统.xlsx", "AD空调人防系统"));
        funcids.addAll(readSheet("WSDW", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "DW生活给水系统"));
        funcids.addAll(readSheet("WSDH", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "DH生活热水系统"));
        funcids.addAll(readSheet("WSRW", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "RW中水系统"));
        funcids.addAll(readSheet("WSDD", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "DD直饮水系统"));
        funcids.addAll(readSheet("WSST", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "ST污水处理系统"));
        funcids.addAll(readSheet("WSSI", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "SI喷灌系统"));
        funcids.addAll(readSheet("WSWS", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "WS水景系统"));
        funcids.addAll(readSheet("WSWP", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "WP泳池系统"));
        funcids.addAll(readSheet("WSFG", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "FG燃气系统"));
        funcids.addAll(readSheet("WSWH", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "WH给排水电伴热系统"));
        funcids.addAll(readSheet("WSWD", "/附表7-系统类对象分类属性点表/附表7.4-给排水专业系统.xlsx", "WD给排水人防系统"));
        funcids.addAll(readSheet("FFFA", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "FA火灾报警系统"));
        funcids.addAll(readSheet("FFGA", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "GA燃气报警系统"));
        funcids.addAll(readSheet("FFEA", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "EA漏电火灾报警系统"));
        funcids.addAll(readSheet("FFBM", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "BM紧急广播及背景音乐系统"));
        funcids.addAll(readSheet("FFFS", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "FS消防给水系统"));
        funcids.addAll(readSheet("FFGE", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "GE气体灭火系统"));
        funcids.addAll(readSheet("FFFE", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "FE灭火器系统"));
        funcids.addAll(readSheet("FFSC", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "SC防排烟系统"));
        funcids.addAll(readSheet("FFFR", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "FR防火卷帘门系统"));
        funcids.addAll(readSheet("FFEE", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "EE应急照明及疏散指示系统"));
        funcids.addAll(readSheet("FFKE", "/附表7-系统类对象分类属性点表/附表7.5-消防专业系统.xlsx", "KE厨房自动灭火系统"));
        funcids.addAll(readSheet("SPVS", "/附表7-系统类对象分类属性点表/附表7.6-安防专业系统.xlsx", "VS视频监控系统"));
        funcids.addAll(readSheet("SPNP", "/附表7-系统类对象分类属性点表/附表7.6-安防专业系统.xlsx", "NP巡更系统"));
        funcids.addAll(readSheet("SPEG", "/附表7-系统类对象分类属性点表/附表7.6-安防专业系统.xlsx", "EG门禁系统"));
        funcids.addAll(readSheet("SPIA", "/附表7-系统类对象分类属性点表/附表7.6-安防专业系统.xlsx", "IA入侵报警系统"));
    }

    private void importEquipment(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("equipment", "/附表6-机电精装类对象通用属性点表.xlsx", "设备类"));
        funcids.addAll(readSheet("SETDTF", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDTF变压器"));
        funcids.addAll(readSheet("SETDHS", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDHS高压开关柜"));
        funcids.addAll(readSheet("SETDLS", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDLS低压开关柜"));
        funcids.addAll(readSheet("SETDDS", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDDS直流屏"));
        funcids.addAll(readSheet("SETDIV", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDIV逆变器"));
        funcids.addAll(readSheet("SETDBP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDBP变配电母线插接箱"));
        funcids.addAll(readSheet("SETDCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.1-变配电系统设备.xlsx", "TDCU变配电控制箱"));
        funcids.addAll(readSheet("SESDCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.10-强电人防系统设备.xlsx", "SDCU强电人防控制箱"));
        funcids.addAll(readSheet("SEDGDG", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGDG柴油发电机"));
        funcids.addAll(readSheet("SEDGDT", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGDT柴发储油箱"));
        funcids.addAll(readSheet("SEDGPP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGPP柴发输油泵"));
        funcids.addAll(readSheet("SEDGJH", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGJH柴发水套加热器"));
        funcids.addAll(readSheet("SEDGEP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGEP柴发尾气净化装置"));
        funcids.addAll(readSheet("SEDGCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.2-柴发机房系统设备.xlsx", "DGCU柴发控制箱"));
        funcids.addAll(readSheet("SEBPBP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.3-备用电源系统设备.xlsx", "BPBP备用电源"));
        funcids.addAll(readSheet("SEBPSP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.3-备用电源系统设备.xlsx", "BPSP太阳能电池板"));
        funcids.addAll(readSheet("SEBPWG", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.3-备用电源系统设备.xlsx", "BPWG风力发电装置"));
        funcids.addAll(readSheet("SEBPHT", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.3-备用电源系统设备.xlsx", "BPHT备用电源主机"));
        funcids.addAll(readSheet("SEBPCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.3-备用电源系统设备.xlsx", "BPCU备用电源控制箱"));
        funcids.addAll(readSheet("SEEPCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.4-机房动力系统设备.xlsx", "EPCU机房动力控制箱"));
        funcids.addAll(readSheet("SEOPCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.5-室外动力系统设备.xlsx", "OPCU室外动力控制箱"));
        funcids.addAll(readSheet("SEELEL", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.6-电梯系统设备.xlsx", "ELEL直梯"));
        funcids.addAll(readSheet("SEELES", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.6-电梯系统设备.xlsx", "ELES扶梯"));
        funcids.addAll(readSheet("SEELCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.6-电梯系统设备.xlsx", "ELCU电梯控制箱"));
        funcids.addAll(readSheet("SEELET", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.6-电梯系统设备.xlsx", "ELET电梯曳引机"));
        funcids.addAll(readSheet("SELTLT", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.7-照明系统设备.xlsx", "LTLT照明灯具"));
        funcids.addAll(readSheet("SELTCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.7-照明系统设备.xlsx", "LTCU照明控制箱"));
        funcids.addAll(readSheet("SELTCP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.7-照明系统设备.xlsx", "LTCP照明控制面板"));
        funcids.addAll(readSheet("SELTCC", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.7-照明系统设备.xlsx", "LTCC照明回路（预计330后删除）"));
        funcids.addAll(readSheet("SELTLG", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.7-照明系统设备.xlsx", "LTLG照明灯组（预计330后删除）"));
        funcids.addAll(readSheet("SETPCU", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.8-租户配电系统设备.xlsx", "TPCU租户配电控制箱"));
        funcids.addAll(readSheet("SETPBP", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.8-租户配电系统设备.xlsx", "TPBP租户母线插接箱"));
        funcids.addAll(readSheet("SELPAT", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.9-雷电防护系统设备.xlsx", "LPAT接闪器"));
        funcids.addAll(readSheet("SELPDL", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.9-雷电防护系统设备.xlsx", "LPDL引下线"));
        funcids.addAll(readSheet("SELPGD", "/附表8-设备类对象分类属性点表/附表8.1-强电专业设备/附表8.1.9-雷电防护系统设备.xlsx", "LPGD接地装置"));
        funcids.addAll(readSheet("WEBAHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BAHT楼控主机"));
        funcids.addAll(readSheet("WEBACU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BACU楼控控制箱"));
        funcids.addAll(readSheet("WEBADC", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BADC楼控数据采集器"));
        funcids.addAll(readSheet("WEBAPS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BAPS楼控电源供应器"));
        funcids.addAll(readSheet("WEBAEC", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BAEC楼控机柜"));
        funcids.addAll(readSheet("WEBADS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BADS楼控显示屏"));
        funcids.addAll(readSheet("WEBACP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.1-建筑设备控制系统设备.xlsx", "BACP楼控控制面板"));
        funcids.addAll(readSheet("WEEMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.10-能源管理系统设备.xlsx", "EMHT能源管理主机"));
        funcids.addAll(readSheet("WEEMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.10-能源管理系统设备.xlsx", "EMCU能源管理控制箱"));
        funcids.addAll(readSheet("WEMMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.11-气象监测系统设备.xlsx", "MMHT气象监测主机"));
        funcids.addAll(readSheet("WEMMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.11-气象监测系统设备.xlsx", "MMCU气象监测控制箱"));
        funcids.addAll(readSheet("WEMMMS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.11-气象监测系统设备.xlsx", "MMMS气象监测站"));
        funcids.addAll(readSheet("WECMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.12-收银管理系统设备.xlsx", "CMHT收银管理主机"));
        funcids.addAll(readSheet("WECMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.12-收银管理系统设备.xlsx", "CMCU收银管理控制箱"));
        funcids.addAll(readSheet("WEOFTL", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFTL办公电话"));
        funcids.addAll(readSheet("WEOFCM", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFCM办公摄像头"));
        funcids.addAll(readSheet("WEOFCP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFCP办公控制面板"));
        funcids.addAll(readSheet("WEOFCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFCU办公控制箱"));
        funcids.addAll(readSheet("WEOFDS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFDS办公显示屏"));
        funcids.addAll(readSheet("WEOFFE", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFFE办公前端设备"));
        funcids.addAll(readSheet("WEOFHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFHT办公主机"));
        funcids.addAll(readSheet("WEOFSP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFSP办公扬声器"));
        funcids.addAll(readSheet("WEOFCK", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFCK办公时钟"));
        funcids.addAll(readSheet("WEOFPT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFPT办公打印机"));
        funcids.addAll(readSheet("WEOFMP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFMP办公话筒"));
        funcids.addAll(readSheet("WEOFPJ", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFPJ办公投影仪"));
        funcids.addAll(readSheet("WEOFPS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFPS办公投影幕"));
        funcids.addAll(readSheet("WEOFTV", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.13-办公系统设备.xlsx", "OFTV办公电视机"));
        funcids.addAll(readSheet("WETVFE", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.2-电视信号系统设备.xlsx", "TVFE电视前端设备"));
        funcids.addAll(readSheet("WETVTV", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.2-电视信号系统设备.xlsx", "TVTV电视机"));
        funcids.addAll(readSheet("WETVCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.2-电视信号系统设备.xlsx", "TVCU电视信号控制箱"));
        funcids.addAll(readSheet("WEMIHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MIHT多媒体主机"));
        funcids.addAll(readSheet("WEMIPL", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MIPL播放器"));
        funcids.addAll(readSheet("WEMIDS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MIDS多媒体显示屏"));
        funcids.addAll(readSheet("WEMIST", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MIST自助终端机"));
        funcids.addAll(readSheet("WEMIFE", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MIFE多媒体前端设备"));
        funcids.addAll(readSheet("WEMICU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.3-多媒体信息发布系统设备.xlsx", "MICU多媒体控制箱"));
        funcids.addAll(readSheet("WEWTWT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.4-无线对讲系统设备.xlsx", "WTWT对讲机"));
        funcids.addAll(readSheet("WEWTRS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.4-无线对讲系统设备.xlsx", "WTRS中继台"));
        funcids.addAll(readSheet("WEWTCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.4-无线对讲系统设备.xlsx", "WTCU无线对讲控制箱"));
        funcids.addAll(readSheet("WEGMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMHT车库主机"));
        funcids.addAll(readSheet("WEGMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMCU车库控制箱"));
        funcids.addAll(readSheet("WEGMCM", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMCM车库摄像头"));
        funcids.addAll(readSheet("WEGMDS", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMDS车库显示屏"));
        funcids.addAll(readSheet("WEGMGT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMGT进出闸机"));
        funcids.addAll(readSheet("WEGMMP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMMP机械车位"));
        funcids.addAll(readSheet("WEGMCP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMCP充电桩"));
        funcids.addAll(readSheet("WEGMPD", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMPD车位检测器"));
        funcids.addAll(readSheet("WEGMGL", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMGL车位引导灯"));
        funcids.addAll(readSheet("WEGMLP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMLP升降防撞柱"));
        funcids.addAll(readSheet("WEGMPL", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.5-车库管理系统设备.xlsx", "GMPL车库地锁"));
        funcids.addAll(readSheet("WELNHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNHT服务器主机"));
        funcids.addAll(readSheet("WELNRT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNRT路由器"));
        funcids.addAll(readSheet("WELNEX", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNEX交换机"));
        funcids.addAll(readSheet("WELNHF", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNHF硬件防火墙"));
        funcids.addAll(readSheet("WELNAC", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNAC无线控制器"));
        funcids.addAll(readSheet("WELNAP", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNAP无线AP点位"));
        funcids.addAll(readSheet("WELNCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.6-本地网络系统设备.xlsx", "LNCU网络控制箱"));
        funcids.addAll(readSheet("WEMAHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.7-移动通信信号放大系统设备.xlsx", "MAHT移动通信信号放大主机"));
        funcids.addAll(readSheet("WEMAAT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.7-移动通信信号放大系统设备.xlsx", "MAAT移动通信信号放大天线"));
        funcids.addAll(readSheet("WEMACU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.7-移动通信信号放大系统设备.xlsx", "MACU移动通信信号放大控制箱"));
        funcids.addAll(readSheet("WETMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.8-租户管理系统设备.xlsx", "TMHT租户管理主机"));
        funcids.addAll(readSheet("WETMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.8-租户管理系统设备.xlsx", "TMCU租户管理控制箱"));
        funcids.addAll(readSheet("WEPMHT", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.9-客流管理系统设备.xlsx", "PMHT客流管理主机"));
        funcids.addAll(readSheet("WEPMCU", "/附表8-设备类对象分类属性点表/附表8.2-弱电专业设备/附表8.2.9-客流管理系统设备.xlsx", "PMCU客流管理控制箱"));
        funcids.addAll(readSheet("ACCCCC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCC离心式冷水机组"));
        funcids.addAll(readSheet("ACCCSC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCSC螺杆式冷水机组"));
        funcids.addAll(readSheet("ACCCPC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCPC活塞式冷水机组"));
        funcids.addAll(readSheet("ACCCAC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCAC吸收式冷水机组"));
        funcids.addAll(readSheet("ACCCAH", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCAH空调空气源热泵"));
        funcids.addAll(readSheet("ACCCWH", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCWH空调水源热泵"));
        funcids.addAll(readSheet("ACCCGH", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCGH空调地源热泵"));
        funcids.addAll(readSheet("ACCCOT", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCOT冷却塔"));
        funcids.addAll(readSheet("ACCCCP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCP供冷冷冻水泵"));
        funcids.addAll(readSheet("ACCCOP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCOP供冷冷却水泵"));
        funcids.addAll(readSheet("ACCCGP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCGP供冷乙二醇泵"));
        funcids.addAll(readSheet("ACCCFP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCFP供冷补水泵"));
        funcids.addAll(readSheet("ACCCCF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCF供冷定压补水装置"));
        funcids.addAll(readSheet("ACCCPT", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCPT供冷压力罐"));
        funcids.addAll(readSheet("ACCCHE", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCHE供冷换热器"));
        funcids.addAll(readSheet("ACCCVD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCVD供冷真空脱气机"));
        funcids.addAll(readSheet("ACCCCD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCD供冷水加药装置"));
        funcids.addAll(readSheet("ACCCSD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCSD供冷软化水装置"));
        funcids.addAll(readSheet("ACCCTU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCTU供冷全程水处理仪"));
        funcids.addAll(readSheet("ACCCST", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCST供冷蓄冷热槽"));
        funcids.addAll(readSheet("ACCCDB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCDB供冷分水器"));
        funcids.addAll(readSheet("ACCCCL", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCL供冷集水器"));
        funcids.addAll(readSheet("ACCCWT", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCWT供冷水箱"));
        funcids.addAll(readSheet("ACCCOC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCOC供冷在线清洗装置"));
        funcids.addAll(readSheet("ACCCTC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCTC供冷伴热电缆"));
        funcids.addAll(readSheet("ACCCCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.1-中央供冷系统设备.xlsx", "CCCU供冷控制箱"));
        funcids.addAll(readSheet("ACCHCB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHCB供热燃煤锅炉"));
        funcids.addAll(readSheet("ACCHFB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHFB供热燃油锅炉"));
        funcids.addAll(readSheet("ACCHGB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHGB供热燃气锅炉"));
        funcids.addAll(readSheet("ACCHEB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHEB供热电锅炉"));
        funcids.addAll(readSheet("ACCHHP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHHP供热水泵"));
        funcids.addAll(readSheet("ACCHFP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHFP供热补水泵"));
        funcids.addAll(readSheet("ACCHCF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHCF供热定压补水装置"));
        funcids.addAll(readSheet("ACCHPT", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHPT供热压力罐"));
        funcids.addAll(readSheet("ACCHHE", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHHE供热换热器"));
        funcids.addAll(readSheet("ACCHVD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHVD供热真空脱气机"));
        funcids.addAll(readSheet("ACCHCD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHCD供热水加药装置"));
        funcids.addAll(readSheet("ACCHSD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHSD供热软化水装置"));
        funcids.addAll(readSheet("ACCHTU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHTU供热全程水处理仪"));
        funcids.addAll(readSheet("ACCHST", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHST供热蓄冷热槽"));
        funcids.addAll(readSheet("ACCHDB", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHDB供热分水器"));
        funcids.addAll(readSheet("ACCHCL", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHCL供热集水器"));
        funcids.addAll(readSheet("ACCHWT", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHWT供热水箱"));
        funcids.addAll(readSheet("ACCHOC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHOC供热在线清洗装置"));
        funcids.addAll(readSheet("ACCHBF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHBF生物质炊暖炉"));
        funcids.addAll(readSheet("ACCHCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.2-中央供热系统设备.xlsx", "CHCU供热控制箱"));
        funcids.addAll(readSheet("ACATAH", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATAH空调机组"));
        funcids.addAll(readSheet("ACATFU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATFU新风机组"));
        funcids.addAll(readSheet("ACATFC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATFC风机盘管"));
        funcids.addAll(readSheet("ACATSA", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATSA分体空调"));
        funcids.addAll(readSheet("ACATSI", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATSI分体空调室内机"));
        funcids.addAll(readSheet("ACATSO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATSO分体空调室外机"));
        funcids.addAll(readSheet("ACATVR", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATVR变频多联机"));
        funcids.addAll(readSheet("ACATVI", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATVI变频多联机室内机"));
        funcids.addAll(readSheet("ACATVO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATVO变频多联机室外机"));
        funcids.addAll(readSheet("ACATVA", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATVA变风量箱"));
        funcids.addAll(readSheet("ACATFA", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATFA地板空调器"));
        funcids.addAll(readSheet("ACATIO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATIO空调风口"));
        funcids.addAll(readSheet("ACATRD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATRD散热器"));
        funcids.addAll(readSheet("ACATIR", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATIR红外辐射单元"));
        funcids.addAll(readSheet("ACATFH", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATFH地板采暖设备"));
        funcids.addAll(readSheet("ACATHD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATHD空调加湿器"));
        funcids.addAll(readSheet("ACATMF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATMF空调消声器"));
        funcids.addAll(readSheet("ACATPC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATPC空调静压箱"));
        funcids.addAll(readSheet("ACATCA", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATCA定风量箱"));
        funcids.addAll(readSheet("ACATCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.3-空调末端系统设备.xlsx", "ATCU空调末端控制箱"));
        funcids.addAll(readSheet("ACVTSF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTSF通风风机"));
        funcids.addAll(readSheet("ACVTAC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTAC热风幕"));
        funcids.addAll(readSheet("ACVTAP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTAP空气净化器"));
        funcids.addAll(readSheet("ACVTDO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTDO通风除味装置"));
        funcids.addAll(readSheet("ACVTIO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTIO通风风口"));
        funcids.addAll(readSheet("ACVTMF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTMF通风消声器"));
        funcids.addAll(readSheet("ACVTPC", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTPC通风静压箱"));
        funcids.addAll(readSheet("ACVTCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTCU通风控制箱"));
        funcids.addAll(readSheet("ACVTCP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.4-通风系统设备.xlsx", "VTCP通风控制面板"));
        funcids.addAll(readSheet("ACKLSF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.5-厨房排油烟系统设备.xlsx", "KLSF厨房排油烟风机"));
        funcids.addAll(readSheet("ACKLAP", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.5-厨房排油烟系统设备.xlsx", "KLAP厨房油烟净化器"));
        funcids.addAll(readSheet("ACKLCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.5-厨房排油烟系统设备.xlsx", "KLCU厨房排油烟控制箱"));
        funcids.addAll(readSheet("ACKLIO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.5-厨房排油烟系统设备.xlsx", "KLIO厨房排油烟风口"));
        funcids.addAll(readSheet("ACADSF", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.6-空调人防系统设备.xlsx", "ADSF空调人防风机"));
        funcids.addAll(readSheet("ACADFD", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.6-空调人防系统设备.xlsx", "ADFD滤毒除湿机"));
        funcids.addAll(readSheet("ACADCU", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.6-空调人防系统设备.xlsx", "ADCU空调人防控制箱"));
        funcids.addAll(readSheet("ACADIO", "/附表8-设备类对象分类属性点表/附表8.3-空调专业设备/附表8.3.6-空调人防系统设备.xlsx", "ADIO空调人防风口"));
        funcids.addAll(readSheet("WSDWSU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWSU生活给水供水机组"));
        funcids.addAll(readSheet("WSDWTS", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWTS生活给水水箱消毒器"));
        funcids.addAll(readSheet("WSDWUS", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWUS生活给水紫外线消毒器"));
        funcids.addAll(readSheet("WSDWWT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWWT生活给水储水箱"));
        funcids.addAll(readSheet("WSDWPT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWPT生活给水压力罐"));
        funcids.addAll(readSheet("WSDWPP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWPP生活给水水泵"));
        funcids.addAll(readSheet("WSDWCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.1-生活给水系统设备.xlsx", "DWCU生活给水控制箱"));
        funcids.addAll(readSheet("WSWHTC", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.10-给排水电伴热系统设备.xlsx", "WHTC给排水伴热电缆"));
        funcids.addAll(readSheet("WSWHIB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.10-给排水电伴热系统设备.xlsx", "WHIB给排水伴热保温器"));
        funcids.addAll(readSheet("WSWHCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.10-给排水电伴热系统设备.xlsx", "WHCU给排水伴热控制箱"));
        funcids.addAll(readSheet("WSWDWT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.11-给排水人防系统设备.xlsx", "WDWT给排水人防储水箱"));
        funcids.addAll(readSheet("WSWDCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.11-给排水人防系统设备.xlsx", "WDCU给排水人防控制箱"));
        funcids.addAll(readSheet("WSDHCB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHCB生活热水燃煤锅炉"));
        funcids.addAll(readSheet("WSDHFB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHFB生活热水燃油锅炉"));
        funcids.addAll(readSheet("WSDHGB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHGB生活热水燃气锅炉"));
        funcids.addAll(readSheet("WSDHEB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHEB生活热水电锅炉"));
        funcids.addAll(readSheet("WSDHAH", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHAH生活热水空气源热泵"));
        funcids.addAll(readSheet("WSDHGH", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHGH生活热水燃气热水器"));
        funcids.addAll(readSheet("WSDHEH", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHEH生活热水电热水器"));
        funcids.addAll(readSheet("WSDHSC", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHSC生活热水太阳能集热器"));
        funcids.addAll(readSheet("WSDHHA", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHHA生活热水辅热设备"));
        funcids.addAll(readSheet("WSDHHE", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHHE生活热水换热器"));
        funcids.addAll(readSheet("WSDHSU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", " DHSU生活热水供水机组"));
        funcids.addAll(readSheet("WSDHHP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHHP生活热水水泵"));
        funcids.addAll(readSheet("WSDHSD", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHSD生活热水软化水装置"));
        funcids.addAll(readSheet("WSDHCF", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHCF生活热水定压补水装置"));
        funcids.addAll(readSheet("WSDHPT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHPT生活热水压力罐"));
        funcids.addAll(readSheet("WSDHST", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHST生活热水蓄冷热槽"));
        funcids.addAll(readSheet("WSDHWT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHWT生活热水储水箱"));
        funcids.addAll(readSheet("WSDHCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.2-生活热水系统设备.xlsx", "DHCU生活热水控制箱"));
        funcids.addAll(readSheet("WSRWSU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWSU中水供水机组"));
        funcids.addAll(readSheet("WSRWTU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWTU中水处理机组"));
        funcids.addAll(readSheet("WSRWWT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWWT中水储水箱"));
        funcids.addAll(readSheet("WSRWRC", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWRC雨水收集设备"));
        funcids.addAll(readSheet("WSRWPT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWPT中水供水压力罐"));
        funcids.addAll(readSheet("WSRWPP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWPP中水供水水泵"));
        funcids.addAll(readSheet("WSRWCD", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWCD中水水加药装置"));
        funcids.addAll(readSheet("WSLAFT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "LAFT中水过滤器"));
        funcids.addAll(readSheet("WSRWCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.3-中水系统设备.xlsx", "RWCU中水控制箱"));
        funcids.addAll(readSheet("WSDDTU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.4-直饮水系统设备.xlsx", "DDTU直饮水处理机组"));
        funcids.addAll(readSheet("WSDDIH", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.4-直饮水系统设备.xlsx", "DDIH直饮水即时加热器"));
        funcids.addAll(readSheet("WSDDCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.4-直饮水系统设备.xlsx", "DDCU直饮水控制箱"));
        funcids.addAll(readSheet("WSSTLU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STLU污废水一体式提升机组"));
        funcids.addAll(readSheet("WSSTSP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STSP潜污泵"));
        funcids.addAll(readSheet("WSSTOR", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STOR餐饮除油成套设备"));
        funcids.addAll(readSheet("WSSTST", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STST化粪池"));
        funcids.addAll(readSheet("WSSTCP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STCP集水坑"));
        funcids.addAll(readSheet("WSSTOS", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STOS隔油池"));
        funcids.addAll(readSheet("WSSTQM", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STQM污水水质监测仪"));
        funcids.addAll(readSheet("WSSTCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.5-污水处理系统设备.xlsx", "STCU污水控制箱"));
        funcids.addAll(readSheet("WSSISU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.6-喷灌系统设备.xlsx", "SISU喷灌机组"));
        funcids.addAll(readSheet("WSSISN", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.6-喷灌系统设备.xlsx", "SISN喷灌喷头"));
        funcids.addAll(readSheet("WSSICU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.6-喷灌系统设备.xlsx", "SICU喷灌控制箱"));
        funcids.addAll(readSheet("WSWSCF", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.7-水景系统设备.xlsx", "WSCF水景循环过滤机组"));
        funcids.addAll(readSheet("WSWSSN", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.7-水景系统设备.xlsx", "WSSN水景喷头"));
        funcids.addAll(readSheet("WSWSCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.7-水景系统设备.xlsx", "WSCU水景控制箱"));
        funcids.addAll(readSheet("WSWSLT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.7-水景系统设备.xlsx", "WSLT水景灯具"));
        funcids.addAll(readSheet("WSWSPP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.7-水景系统设备.xlsx", "WSPP水景水泵"));
        funcids.addAll(readSheet("WSWPCF", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPCF泳池循环过滤机组"));
        funcids.addAll(readSheet("WSWPPP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPPP泳池循环水泵"));
        funcids.addAll(readSheet("WSWPHE", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPHE泳池换热器"));
        funcids.addAll(readSheet("WSWPOS", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPOS泳池臭氧消毒器"));
        funcids.addAll(readSheet("WSWPQM", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPQM泳池水质监测仪"));
        funcids.addAll(readSheet("WSWPPB", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPPB泳池PH值平衡投药泵"));
        funcids.addAll(readSheet("WSWPOP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPOP泳池氧消毒剂投药泵"));
        funcids.addAll(readSheet("WSWPWT", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPWT泳池水箱"));
        funcids.addAll(readSheet("WSWPCU", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.8-泳池系统设备.xlsx", "WPCU泳池控制箱"));
        funcids.addAll(readSheet("WSFGPA", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.9-燃气系统设备.xlsx", "FGPA燃气调压箱"));
        funcids.addAll(readSheet("WSFGLP", "/附表8-设备类对象分类属性点表/附表8.4-给排水专业设备/附表8.4.9-燃气系统设备.xlsx", "FGLP液化石油气瓶"));
        funcids.addAll(readSheet("FFFAHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FAHT火灾报警主机"));
        funcids.addAll(readSheet("FFFADS", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FADS火灾报警显示屏"));
        funcids.addAll(readSheet("FFFALP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FALP联动琴台"));
        funcids.addAll(readSheet("FFFASE", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FASE火灾探测器"));
        funcids.addAll(readSheet("FFFAAL", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FAAL火灾报警声光报警器"));
        funcids.addAll(readSheet("FFFAMA", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FAMA消防手动报警按钮"));
        funcids.addAll(readSheet("FFFAHA", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FAHA消火栓报警按钮"));
        funcids.addAll(readSheet("FFFATL", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FATL消防电话"));
        funcids.addAll(readSheet("FFFACU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.1-火灾报警系统设备.xlsx", "FACU火灾报警控制箱"));
        funcids.addAll(readSheet("FFEEHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.10-应急照明及疏散指示系统设备.xlsx", "EEHT应急照明及疏散指示主机"));
        funcids.addAll(readSheet("FFEECU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.10-应急照明及疏散指示系统设备.xlsx", "EECU应急照明及疏散指示控制箱"));
        funcids.addAll(readSheet("FFEEEL", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.10-应急照明及疏散指示系统设备.xlsx", "EEEL应急照明灯具"));
        funcids.addAll(readSheet("FFEEEI", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.10-应急照明及疏散指示系统设备.xlsx", "EEEI疏散指示灯牌"));
        funcids.addAll(readSheet("FFKECU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.11-厨房自动灭火系统设备.xlsx", "KECU厨房自动灭火控制箱"));
        funcids.addAll(readSheet("FFKEEC", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.11-厨房自动灭火系统设备.xlsx", "KEEC厨房自动灭火灭火剂容器"));
        funcids.addAll(readSheet("FFKESN", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.11-厨房自动灭火系统设备.xlsx", "KESN厨房自动灭火喷头"));
        funcids.addAll(readSheet("FFGAHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.2-燃气报警系统设备.xlsx", "GAHT燃气报警主机"));
        funcids.addAll(readSheet("FFGASE", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.2-燃气报警系统设备.xlsx", "GASE燃气探测器"));
        funcids.addAll(readSheet("FFGACV", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.2-燃气报警系统设备.xlsx", "GACV燃气切断阀"));
        funcids.addAll(readSheet("FFGACU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.2-燃气报警系统设备.xlsx", "GACU燃气报警控制箱"));
        funcids.addAll(readSheet("FFEAHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.3-漏电火灾报警系统设备.xlsx", "EAHT漏电火灾报警主机"));
        funcids.addAll(readSheet("FFEALS", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.3-漏电火灾报警系统设备.xlsx", "EALS漏电探测器"));
        funcids.addAll(readSheet("FFEACU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.3-漏电火灾报警系统设备.xlsx", "EACU漏电火灾报警控制箱"));
        funcids.addAll(readSheet("FFBMFE", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMFE广播前端设备"));
        funcids.addAll(readSheet("FFBMHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMHT广播主机"));
        funcids.addAll(readSheet("FFBMCU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMCU广播分区控制箱"));
        funcids.addAll(readSheet("FFBMDS", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMDS广播显示屏"));
        funcids.addAll(readSheet("FFBMMP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMMP广播话筒"));
        funcids.addAll(readSheet("FFBMSP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.4-紧急广播及背景音乐系统设备.xlsx", "BMSP广播扬声器"));
        funcids.addAll(readSheet("FFFSHP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSHP消火栓供水加压泵"));
        funcids.addAll(readSheet("FFFSSP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSSP喷淋供水加压泵"));
        funcids.addAll(readSheet("FFFSMP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSMP水喷雾供水加压泵"));
        funcids.addAll(readSheet("FFFSAP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSAP停机坪消防供水加压泵"));
        funcids.addAll(readSheet("FFFSPP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSPP预作用加压泵"));
        funcids.addAll(readSheet("FFFSGP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSGP窗玻璃喷淋泵"));
        funcids.addAll(readSheet("FFFSIP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSIP加密喷淋泵"));
        funcids.addAll(readSheet("FFFSWP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSWP水炮泵"));
        funcids.addAll(readSheet("FFFSPM", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSPM消防稳压泵"));
        funcids.addAll(readSheet("FFFSWM", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSWM消防水炮设备"));
        funcids.addAll(readSheet("FFFSCF", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSCF消防给水定压补水装置"));
        funcids.addAll(readSheet("FFFSPT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSPT消防给水压力罐"));
        funcids.addAll(readSheet("FFFSFT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSFT泡沫储罐组"));
        funcids.addAll(readSheet("FFFSAC", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSAC消防空压机"));
        funcids.addAll(readSheet("FFFSWV", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSWV湿式报警阀组"));
        funcids.addAll(readSheet("FFFSDV", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSDV干式报警阀组"));
        funcids.addAll(readSheet("FFFSPV", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSPV预作用报警阀组"));
        funcids.addAll(readSheet("FFFSHB", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSHB消火栓箱"));
        funcids.addAll(readSheet("FFFSOH", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSOH室外消火栓"));
        funcids.addAll(readSheet("FFFSPC", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSPC消防水泵接合器"));
        funcids.addAll(readSheet("FFFSTC", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSTC消防伴热电缆"));
        funcids.addAll(readSheet("FFFSET", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSET消防末端试水装置"));
        funcids.addAll(readSheet("FFFSWT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSWT消防水箱"));
        funcids.addAll(readSheet("FFFSTS", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSTS消防水箱消毒器"));
        funcids.addAll(readSheet("FFFSFP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSFP消防补水泵"));
        funcids.addAll(readSheet("FFFSSN", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSSN消防喷头"));
        funcids.addAll(readSheet("FFFSCP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSCP消火栓控制面板"));
        funcids.addAll(readSheet("FFFSHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSHT消防给水主机"));
        funcids.addAll(readSheet("FFFSCU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.5-消防给水系统设备.xlsx", "FSCU消防给水控制箱"));
        funcids.addAll(readSheet("FFGEBG", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.6-气体灭火系统设备.xlsx", "GEBG气体灭火瓶组"));
        funcids.addAll(readSheet("FFGESB", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.6-气体灭火系统设备.xlsx", "GESB气体灭火启动瓶"));
        funcids.addAll(readSheet("FFGEHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.6-气体灭火系统设备.xlsx", "GEHT气体灭火主机"));
        funcids.addAll(readSheet("FFGECU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.6-气体灭火系统设备.xlsx", "GECU气体灭火控制箱"));
        funcids.addAll(readSheet("FFGESN", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.6-气体灭火系统设备.xlsx", "GESN气体灭火喷头"));
        funcids.addAll(readSheet("FFFEFE", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.7-灭火器系统设备.xlsx", "FEFE灭火器"));
        funcids.addAll(readSheet("FFSCEF", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.8-防排烟系统设备.xlsx", "SCEF防排烟风机"));
        funcids.addAll(readSheet("FFSCIO", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.8-防排烟系统设备.xlsx", "SCIO排烟风口"));
        funcids.addAll(readSheet("FFSCHW", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.8-防排烟系统设备.xlsx", "SCHW电动挡烟垂壁"));
        funcids.addAll(readSheet("FFSCSD", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.8-防排烟系统设备.xlsx", "SCSD防火排烟阀"));
        funcids.addAll(readSheet("FFSCCU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.8-防排烟系统设备.xlsx", "SCCU防排烟控制箱"));
        funcids.addAll(readSheet("FFFRFR", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.9-防火卷帘门系统设备.xlsx", "FRFR防火卷帘门"));
        funcids.addAll(readSheet("FFFRFD", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.9-防火卷帘门系统设备.xlsx", "FRFD防火门"));
        funcids.addAll(readSheet("FFFRHT", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.9-防火卷帘门系统设备.xlsx", "FRHT防火卷帘门主机"));
        funcids.addAll(readSheet("FFFRCP", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.9-防火卷帘门系统设备.xlsx", "FRCP防火卷帘门控制面板"));
        funcids.addAll(readSheet("FFFRCU", "/附表8-设备类对象分类属性点表/附表8.5-消防专业设备/附表8.5.9-防火卷帘门系统设备.xlsx", "FRCU防火卷帘门控制箱"));
        funcids.addAll(readSheet("SPVSHT", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSHT监控主机"));
        funcids.addAll(readSheet("SPVSCM", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSCM监控摄像头"));
        funcids.addAll(readSheet("SPVSFE", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSFE监控前端设备"));
        funcids.addAll(readSheet("SPVSVM", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSVM监视器"));
        funcids.addAll(readSheet("SPVSDR", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSDR硬盘录像机"));
        funcids.addAll(readSheet("SPVSCP", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSCP监控控制面板"));
        funcids.addAll(readSheet("SPVSCU", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.1-视频监控系统设备.xlsx", "VSCU监控控制箱"));
        funcids.addAll(readSheet("SPNPHT", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.2-巡更系统设备.xlsx", "NPHT巡更主机"));
        funcids.addAll(readSheet("SPNPCU", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.2-巡更系统设备.xlsx", "NPCU巡更控制箱"));
        funcids.addAll(readSheet("SPNPCP", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.2-巡更系统设备.xlsx", "NPCP巡更通讯座"));
        funcids.addAll(readSheet("SPNPPS", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.2-巡更系统设备.xlsx", "NPPS巡更棒"));
        funcids.addAll(readSheet("SPEGHT", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGHT门禁主机"));
        funcids.addAll(readSheet("SPEGCU", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGCU门禁控制箱"));
        funcids.addAll(readSheet("SPEGCR", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGCR门禁读卡器"));
        funcids.addAll(readSheet("SPEGWT", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGWT门禁对讲机"));
        funcids.addAll(readSheet("SPEGTK", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGTK破胎器"));
        funcids.addAll(readSheet("SPEGDL", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGDL门禁门锁"));
        funcids.addAll(readSheet("SPEGBG", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGBG破玻璃按钮"));
        funcids.addAll(readSheet("SPEGCP", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGCP门禁控制面板"));
        funcids.addAll(readSheet("SPEGFG", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.3-门禁系统设备.xlsx", "EGFG速通门"));
        funcids.addAll(readSheet("SPIAHT", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IAHT入侵报警主机"));
        funcids.addAll(readSheet("SPIACU", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IACU入侵报警控制箱"));
        funcids.addAll(readSheet("SPIAMA", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IAMA入侵报警手动报警按钮"));
        funcids.addAll(readSheet("SPIAAL", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IAAL入侵报警声光报警器"));
        funcids.addAll(readSheet("SPIACP", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IACP入侵报警控制面板"));
        funcids.addAll(readSheet("SPIASE", "/附表8-设备类对象分类属性点表/附表8.6-安防专业设备/附表8.6.4-入侵报警系统设备.xlsx", "IASE入侵报警探测器"));
        funcids.addAll(readSheet("CFCSFD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSFD基础"));
        funcids.addAll(readSheet("CFCSCL", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSCL柱"));
        funcids.addAll(readSheet("CFCSGD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSGD梁"));
        funcids.addAll(readSheet("CFCSTR", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSTR桁架"));
        funcids.addAll(readSheet("CFCSWL", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSWL墙"));
        funcids.addAll(readSheet("CFCSFL", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSFL楼板"));
        funcids.addAll(readSheet("CFCSRF", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSRF屋顶"));
        funcids.addAll(readSheet("CFCSSW", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.1-土建结构设备.xlsx", "CSSW楼梯"));
        funcids.addAll(readSheet("CFBECW", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BECW幕墙"));
        funcids.addAll(readSheet("CFBEBC", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEBC呼吸式幕墙"));
        funcids.addAll(readSheet("CFBELR", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BELR采光顶"));
        funcids.addAll(readSheet("CFBEDR", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEDR门"));
        funcids.addAll(readSheet("CFBEWN", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEWN窗"));
        funcids.addAll(readSheet("CFBEAW", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEAW雨篷"));
        funcids.addAll(readSheet("CFBEES", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEES电动遮阳帘"));
        funcids.addAll(readSheet("CFBEMT", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BEMT遮阳电机"));
        funcids.addAll(readSheet("CFBECT", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.2-围护结构设备.xlsx", "BECT普通遮阳帘"));
        funcids.addAll(readSheet("CFIDWS", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDWS盥洗盆"));
        funcids.addAll(readSheet("CFIDTL", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDTL坐便器"));
        funcids.addAll(readSheet("CFIDSP", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDSP蹲便器"));
        funcids.addAll(readSheet("CFIDUR", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDUR小便器"));
        funcids.addAll(readSheet("CFIDHD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDHD干手机"));
        funcids.addAll(readSheet("CFIDBT", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDBT浴缸"));
        funcids.addAll(readSheet("CFIDSK", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDSK洗碗槽"));
        funcids.addAll(readSheet("CFIDSC", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDSC插座"));
        funcids.addAll(readSheet("CFIDFN", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDFN家具"));
        funcids.addAll(readSheet("CFIDCL", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDCL吊顶"));
        funcids.addAll(readSheet("CFIDFD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.3-室内装饰设备.xlsx", "IDFD地漏"));
        funcids.addAll(readSheet("CFCADM", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CADM装饰材料"));
        funcids.addAll(readSheet("CFCAHD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAHD栏杆"));
        funcids.addAll(readSheet("CFCASB", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CASB减速带"));
        funcids.addAll(readSheet("CFCAST", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAST地桩"));
        funcids.addAll(readSheet("CFCADB", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CADB展示板"));
        funcids.addAll(readSheet("CFCAID", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAID标识"));
        funcids.addAll(readSheet("CFCAWC", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAWC擦窗机"));
        funcids.addAll(readSheet("CFCADD", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CADD排水沟"));
        funcids.addAll(readSheet("CFCAWB", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAWB垃圾桶"));
        funcids.addAll(readSheet("CFCAMC", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAMC井盖"));
        funcids.addAll(readSheet("CFCAIS", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAIS检查井"));
        funcids.addAll(readSheet("CFCAOP", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.4-建筑附件设备.xlsx", "CAOP室外道路"));
        funcids.addAll(readSheet("CFPKPS", "/附表8-设备类对象分类属性点表/附表8.7-土建精装专业设备/附表8.7.5-停车场设备.xlsx", "PKPS停车位"));
        funcids.addAll(readSheet("OTSAEW", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.1-强电线路及附件设备.xlsx", "SAEW强电线路"));
        funcids.addAll(readSheet("OTWAEW", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.2-弱电线路及附件设备.xlsx", "WAEW弱电线路"));
        funcids.addAll(readSheet("OTLAPL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.3-液体管道及附件设备.xlsx", "LAPL液体管道"));
        funcids.addAll(readSheet("OTLAFI", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.3-液体管道及附件设备.xlsx", "LAFI水流指示器"));
        funcids.addAll(readSheet("OTLAFT", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.3-液体管道及附件设备.xlsx", "LAFT水管过滤器"));
        funcids.addAll(readSheet("OTAAPL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.4-气体管道及附件设备.xlsx", "AAPL气体管道"));
        funcids.addAll(readSheet("OTAAFT", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.4-气体管道及附件设备.xlsx", "AAFT风道过滤器"));
        funcids.addAll(readSheet("OTSECB", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SECB组合式传感器"));
        funcids.addAll(readSheet("OTSETP", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SETP温度传感器"));
        funcids.addAll(readSheet("OTSERH", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SERH湿度传感器"));
        funcids.addAll(readSheet("OTSEPS", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEPS压力传感器"));
        funcids.addAll(readSheet("OTSECT", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SECT浓度传感器"));
        funcids.addAll(readSheet("OTSESP", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SESP速度传感器"));
        funcids.addAll(readSheet("OTSEDP", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEDP位移传感器"));
        funcids.addAll(readSheet("OTSEFL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEFL流量传感器"));
        funcids.addAll(readSheet("OTSEHT", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEHT热量传感器"));
        funcids.addAll(readSheet("OTSEEE", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEEE电度传感器"));
        funcids.addAll(readSheet("OTSESD", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SESD声音传感器"));
        funcids.addAll(readSheet("OTSEVD", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEVD图像传感器"));
        funcids.addAll(readSheet("OTSEPF", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEPF人流量传感器"));
        funcids.addAll(readSheet("OTSEIL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEIL照度传感器"));
        funcids.addAll(readSheet("OTSEIP", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.5-传感器设备.xlsx", "SEIP室内定位传感器"));
        funcids.addAll(readSheet("OTAEOV", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AEOV通断阀"));
        funcids.addAll(readSheet("OTAEAV", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AEAV调节阀"));
        funcids.addAll(readSheet("OTAECV", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AECV止回阀"));
        funcids.addAll(readSheet("OTAERV", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AERV减压阀"));
        funcids.addAll(readSheet("OTAESV", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AESV安全阀"));
        funcids.addAll(readSheet("OTAERL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AERL继电器"));
        funcids.addAll(readSheet("OTAEFC", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AEFC变频器"));
        funcids.addAll(readSheet("OTAEIL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AEIL提示灯"));
        funcids.addAll(readSheet("OTAEAL", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.6-执行器设备.xlsx", "AEAL声光报警器"));
        funcids.addAll(readSheet("OTXXFZ", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXFZ冷柜（恒温柜）"));
        funcids.addAll(readSheet("OTXXDC", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXDC风干柜"));
        funcids.addAll(readSheet("OTXXAC", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXAC冷风机"));
        funcids.addAll(readSheet("OTXXSC", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXSC消毒柜"));
        funcids.addAll(readSheet("OTXXUA", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXUA无人机"));
        funcids.addAll(readSheet("OTXXCR", "/附表8-设备类对象分类属性点表/附表8.8-其他专业设备/附表8.8.7-其他设备.xlsx", "XXCR扫地机器人"));
    }

    private void importComponent(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("component", "/附表6-机电精装类对象通用属性点表.xlsx", "部件类"));

        funcids.addAll(readSheet("SETDHSIP", "/附表9-部件类对象分类属性点表/附表9.1-强电专业部件.xlsx", "TDHSIP综合保护装置"));
        funcids.addAll(readSheet("SETDLSDW", "/附表9-部件类对象分类属性点表/附表9.1-强电专业部件.xlsx", "TDLSDW低压配电抽屉"));
        funcids.addAll(readSheet("WEBADCBP", "/附表9-部件类对象分类属性点表/附表9.2-弱电专业部件.xlsx", "BADCBP总线端口"));
        funcids.addAll(readSheet("ACCCSCMT", "/附表9-部件类对象分类属性点表/附表9.3-空调专业部件.xlsx", "CCSCMT螺杆式冷水机组电机"));
        funcids.addAll(readSheet("ACCCGHBP", "/附表9-部件类对象分类属性点表/附表9.3-空调专业部件.xlsx", "CCGHBP地埋管"));
        funcids.addAll(readSheet("ACCCOTFN", "/附表9-部件类对象分类属性点表/附表9.3-空调专业部件.xlsx", "CCOTFN冷却塔风机"));
        //funcids.addAll(readSheet("WSSheet1", "/附表9-部件类对象分类属性点表/附表9.4-给排水专业部件.xlsx", "Sheet1"));
        //funcids.addAll(readSheet("FFSheet1", "/附表9-部件类对象分类属性点表/附表9.5-消防专业部件.xlsx", "Sheet1"));
        //funcids.addAll(readSheet("SPSheet1", "/附表9-部件类对象分类属性点表/附表9.6-安防专业部件.xlsx", "Sheet1"));
        funcids.addAll(readSheet("CFCSFDCS", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDCS基础垫层"));
        funcids.addAll(readSheet("CFCSFDWB", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDWB基础防水板"));
        funcids.addAll(readSheet("CFCSFDGD", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDGD基础梁"));
        funcids.addAll(readSheet("CFCSFDPN", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDPN基础嵌板"));
        funcids.addAll(readSheet("CFCSFDAA", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDAA基础抗浮锚杆"));
        funcids.addAll(readSheet("CFCSFDPL", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDPL基础桩"));
        funcids.addAll(readSheet("CFCSFDED", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDED基础电梯基坑"));
        funcids.addAll(readSheet("CFCSFDCP", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSFDCP基础集水坑"));
        funcids.addAll(readSheet("CFCSWLBD", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSWLBD墙体"));
        funcids.addAll(readSheet("CFCSWLIL", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSWLIL墙保温层"));
        funcids.addAll(readSheet("CFCSWLEP", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSWLEP墙预埋件"));
        funcids.addAll(readSheet("CFCSWLCT", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSWLCT墙涂层"));
        funcids.addAll(readSheet("CFCSSWBD", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSSWBD楼梯主体"));
        funcids.addAll(readSheet("CFCSSWRW", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSSWRW楼梯坡道"));
        funcids.addAll(readSheet("CFCSSWAR", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "CSSWAR楼梯扶手"));
        funcids.addAll(readSheet("CFBECWKL", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BECWKL幕墙龙骨"));
        funcids.addAll(readSheet("CFBECWPN", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BECWPN幕墙嵌板"));
        funcids.addAll(readSheet("CFBECWCP", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BECWCP幕墙组件"));
        funcids.addAll(readSheet("CFBELRKL", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BELRKL采光顶龙骨"));
        funcids.addAll(readSheet("CFBELRPN", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BELRPN采光顶嵌板"));
        funcids.addAll(readSheet("CFBELRCP", "/附表9-部件类对象分类属性点表/附表9.7-土建精装专业部件.xlsx", "BELRCP采光顶组件"));
        //funcids.addAll(readSheet("OTSheet1", "/附表9-部件类对象分类属性点表/附表9.8-其他专业部件.xlsx", "Sheet1"));
//        funcids.addAll(readSheet("OTSheet1", "/附表9-部件类对象分类属性点表/附表9.8-其他专业部件.xlsx", "Sheet1"));

    }

    private void importVirtual(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("VOEm", "/附表13-虚拟对象属性点表.xlsx", "能耗模型"));
        funcids.addAll(readSheet("VOSe", "/附表13-虚拟对象属性点表.xlsx", "分项"));
        funcids.addAll(readSheet("VOBc", "/附表13-虚拟对象属性点表.xlsx", "信标"));
        funcids.addAll(readSheet("VOTn", "/附表13-虚拟对象属性点表.xlsx", "租户"));
        funcids.addAll(readSheet("VoWs", "/附表13-虚拟对象属性点表.xlsx", "工作历"));
        funcids.addAll(readSheet("VoBl", "/附表13-虚拟对象属性点表.xlsx", "集团"));
    }

    private void importTool(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("tool", "/附表10-耗材工具类对象通用属性点表.xlsx", "工具类"));
    }

    private void importMaterial(List<FuncidDefModel> funcids) throws IOException {
        funcids.addAll(readSheet("material", "/附表10-耗材工具类对象通用属性点表.xlsx", "耗材类"));
    }

    @Data
    private static class CacheModel {
        private String classCode;
        private String firstTag;
        private String secondTag;
        private String origCode;
        private String name;
        private String unit;
        private String origDataType;
        private String priority; // 优先级
        private String inputMode;
        private String origDataSource; // 字典选择
        private String remark; // 备注
    }

    private List<FuncidDefModel> readSheet(String classCode, String fileName, String sheetName) throws IOException {
        List<FuncidDefModel> data = new LinkedList<>();
        String classFile = basepath + fileName;
        FileInputStream inputStream = new FileInputStream(classFile);
        Workbook workbook = new XSSFWorkbook(inputStream);
        Sheet sheet = workbook.getSheet(sheetName);
        if (sheet == null) {
            return data;
        }
        // 行号从0开始, 从第2行开始读数据
        int startRowNum = 2;
        int lastRowNum = sheet.getLastRowNum();
        CacheModel cache = new CacheModel();
        for (int rowIndex = startRowNum; rowIndex <= lastRowNum; rowIndex++) {
            Row row = sheet.getRow(rowIndex);
            if (row == null) {
                log.info("file: {}, sheet: {}, row[{}] is null", fileName, sheetName, rowIndex);
                continue;
            }
            // 0:firstTag, 1:secondTag, 2:name, 3:origCode, 4:unit, 5:origDataType, 6:priorite, 7:imputMode, 8:origDataSource, 9:remark
            CacheModel target = new CacheModel();
            target.classCode = classCode;
            target.firstTag = (String) ExcelUtils.parseCell(row.getCell(0), "string");
            target.secondTag = (String) ExcelUtils.parseCell(row.getCell(1), "string");
            target.name = (String) ExcelUtils.parseCell(row.getCell(2), "string");
            target.origCode = (String) ExcelUtils.parseCell(row.getCell(3), "string");
            target.unit = (String) ExcelUtils.parseCell(row.getCell(4), "string");
            target.origDataType = (String) ExcelUtils.parseCell(row.getCell(5), "string");
            target.priority = (String) ExcelUtils.parseCell(row.getCell(6), "string");
            target.inputMode = (String) ExcelUtils.parseCell(row.getCell(7), "string");
            target.origDataSource = (String) ExcelUtils.parseCell(row.getCell(8), "string");
            target.remark = (String) ExcelUtils.parseCell(row.getCell(9), "string");
            if (target.origCode == null || "".equals(target.origCode) || "`".equals(target.origCode)) {
                continue;
            }
            // firstTag不为空
            if (target.firstTag != null) {
                cache.firstTag = target.firstTag;
                cache.secondTag = null;
            } else {
                target.firstTag = cache.firstTag;
            }

            // secondTag
            if (target.secondTag != null) {
                cache.secondTag = target.secondTag;
            } else {
                target.secondTag = cache.secondTag;
            }
            FuncidDefModel funcidDefModel = toFuncidDefModel(target);

            if (FuncidUtils.isBase(target.origCode)) {
                continue;
            }
            if (funcidDefModel == null) {
                log.info("file: {}, sheet: {}, row: {} data type [{}] error", fileName, sheetName, rowIndex, target.origDataType);
            } else {
                data.add(funcidDefModel);
            }
        }
        return data;
    }

    @Test
    public void test() {
        ArrayNode array = JsonNodeFactory.instance.arrayNode();
        //查询知识库详情
        String url = rwdeditServer + "/rwdedit/ref/type/infos/query";
        JacksonCriteria criteria = JacksonCriteria.newInstance();
        criteria.add("refKey", "classificationSystem");
        HttpUtils.HttpResult response = httpUtils.post(url, JacksonMapper.toSimpleJson(criteria), 300000);
        String content = response.getContent();
        ObjectNode objectNode = JacksonMapper.toObject(content, ObjectNode.class);
        ArrayNode data = JacksonMapper.getArray(objectNode, "data", JsonNodeFactory.instance.arrayNode());
        for (JsonNode datum : data) {
            ObjectNode obj = (ObjectNode) datum;
            ObjectNode item = array.addObject();
            item.put("code", JacksonMapper.getString(obj, "code"));
            item.put("name", JacksonMapper.getString(obj, "name"));
            String parentCode = JacksonMapper.getString(obj, "parentCode");
            if (parentCode != null) {
                item.put("parentCode", parentCode);
            }
        }
        System.err.println(JacksonMapper.toSimpleJson(array));
    }

}

